# Shareable Markdownlint Config

## 📄 About

Shareable configuration package for [markdownlint](https://github.com/DavidAnson/markdownlint) — a popular linter for Markdown files.

This package provides a consistent and standardized configuration for Markdown linters across projects. By using this package, you can ensure that your Markdown files adhere to the same set of rules and guidelines, improving their readability and maintainability.

### → Purpose

- Make it easy for developers to create Markdown files that meet a minimum standard of quality
- Provide a consistent and standardized configuration for Markdown linters across projects
- Save time and effort by avoiding the need to manually configure markdownlint for each project
- Improve the readability and maintainability of Markdown files

<br>

## 💿 Installation

To use this configuration, you'll need to install `@hybrbase/markdownlint-config` as a development dependency in your mono-repository.

```bash
# Install as dev-dependency in the root of the mono-repository
$ pnpm add -wD \
 markdownlint \
 markdownlint-cli \
 @hybrbase/markdownlint-config
```

This package should be installed in the root of your mono-repository, where you will create a file `.markdownlint.json`. Within your monorepo, you should have a structure with directories for your apps and packages, such as:

```bash
.
├── .markdownlint.json (root)
├── package.json (root)
├── apps
│   └── my-first-app
│       ├── package.json
│       └── ... (other app files)
└── packages
    └── my-first-package
        ├── package.json
        └── ... (other package files)
```

### → Configure

1. Create `.markdownlint.json` file in root of mono-repository and add lines:

   ```json
   {
     "extends": "./node_modules/@hybrbase/markdownlint-config/base.json"
   }
   ```

2. Add scripts to your `package.json`:

   ```bash
   pnpm pkg set scripts.lint:md="markdownlint --fix **/*.md --ignore '**/node_modules/**' --ignore '**/CHANGELOG.md'"
   ```
